@@ -1,8 +1,9 @@
 """Define various calculators."""
 from __future__ import annotations
 
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from enum import Enum
+from typing import Any
 
 from ecowitt2mqtt.helpers.typing import DataValueType
 
@@ -21,4 +22,5 @@ class CalculatedDataPoint:
     data_point_key: str
     value: DataValueType
     unit: str | None = None
+    attributes: dict[str, Any] = field(default_factory=dict)
     data_type: DataPointType = DataPointType.NON_BOOLEAN
